{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Godot.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/gd-script.xml and 'make bootstrap'.
module Skylighting.Syntax.GdScript (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Godot.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgd-script.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGdScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbindings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbuiltinfuncs\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKColor8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKColorN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbytes2var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcartesian2polar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconvert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdb2linear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdecimals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adectime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeg2rad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdict2inst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afposmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afuncref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tget_stack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinst2dict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinstance_from_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finverse_lerp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIis_equal_approx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKis_inf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1is_instance_valid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKis_nan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOis_zero_approx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlerp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlerp_angle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlinear2db\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmove_toward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnearest_po2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nparse_json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpolar2cartesian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKposmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprint_debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprint_stack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprinterr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npush_error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpush_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arad2deg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrand_range\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trand_seed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrandf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrandi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trandomize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrange_lerp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmoothstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstep_decimals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astepify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astr2var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtype_exists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvalidate_json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvar2bytes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avar2str\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aweakref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrapf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrapi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTAU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdefs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nclass_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aonready\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nremotesync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmastersync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npuppetsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\voverloaders\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT_get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2_get_property_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ_init\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r_notification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n_to_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v_enter_tree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n_exit_tree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB_get_configuration_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_physics_process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_ready\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_unhandled_input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4_unhandled_key_input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apreload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vspecialvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionCall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionCall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC[a-zA-Z_][a-zA-Z0-9_]+\\w*\\(\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFunctionCallName\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFunctionCallName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFunctionCallName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN[a-zA-Z_][a-zA-Z0-9_]+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHash comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHash comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINodePath-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINodePath-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNodePath-Var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNodePath-Var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z0-9_]\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apreload\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTAU\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nclass_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmastersync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aonready\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npuppetsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nremotesync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyield\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKColor8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKColorN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbytes2var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcartesian2polar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconvert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdb2linear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdecimals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adectime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeg2rad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdict2inst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afposmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afuncref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tget_stack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinst2dict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinstance_from_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finverse_lerp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIis_equal_approx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKis_inf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1is_instance_valid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKis_nan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOis_zero_approx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlerp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlerp_angle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlinear2db\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmove_toward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnearest_po2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nparse_json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpolar2cartesian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKposmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprint_debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprint_stack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprinterr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npush_error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpush_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arad2deg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrand_range\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trand_seed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrandf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrandi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trandomize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrange_lerp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmoothstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstep_decimals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astepify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astr2var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtype_exists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvalidate_json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvar2bytes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avar2str\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aweakref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrapf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrapi\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v_enter_tree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n_exit_tree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT_get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB_get_configuration_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2_get_property_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ_init\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r_notification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_physics_process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_ready\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n_to_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_unhandled_input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4_unhandled_key_input\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionCall\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnusedVariable\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM[a-zA-Z_][a-zA-Z_0-9]{2,}\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK0x(?:_?[\\da-fA-F])+\\b\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI0b(?:_?[01])+\\b\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE0o(?:_?[0-7])+\\b\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL|([0-9][_0-9]*(\\.[0-9]([_0-9])*)e[\\+\\-]?[0-9][_0-9]*)|([0-9][_0-9]*\\.?e[\\+\\-]?[0-9][_0-9]*)|(([0-9]([_0-9])*)?\\.[0-9][_0-9]*)\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\d[_\\d]*\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDictionary\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTList\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHash comment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVariableVariants\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r!%&*+-/<=>^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple A-string\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple Q-string\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle A-string\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle Q-string\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnusedVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnusedVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC_[a-zA-Z][a-zA-Z0-9_]+\\w*\\(\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN_[a-zA-Z][a-zA-Z0-9_]+\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVariableVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVariableVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH@\"\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINodePath-String\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\$[a-zA-Z0-9_]\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNodePath-Var\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\\\\[\\\\'\"ntrabfv]|\\\\u[0-9A-Fa-f]{4}\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH%%\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL^%.?-?(([1-9][0-9]*)\\*?)?(\\.(([1-9][0-9]*)|\\*))?[scdoxf]|\\{(([a-zA-Z_][a-zA-Z_0-9]*)|[0-9]+)?\\}\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH{{\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH}}\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMario Aichinger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.gd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
