{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for ATS.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/ats.xml and 'make bootstrap'.
module Skylighting.Syntax.Ats (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for ATS.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aats.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1function keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfnx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTprfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprfun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpraxi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcastfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimplmnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timplement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprimplmnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprimplement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTllam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NULO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabstype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babst0ype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabsprop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabsview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babsvtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vabsviewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tabsvt0ype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fabsviewt0ype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclassdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatasort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatatype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdataprop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdataview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdatavtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdataviewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apostfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmacdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmacrodef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnonfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asortdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstacst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstadef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstavar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astaload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymintr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atkindef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apropdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aviewdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvtypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vviewtypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithprop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twithvtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwithviewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEspecial keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$arrpsz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$arrptrsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$delay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$ldelay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$effmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_ntm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_exn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_wrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$extkind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$extype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO$extype_struct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$extval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$lst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$lst_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$lst_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$list_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$list_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$rec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$rec_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$rec_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$record\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t$record_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n$record_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$tup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$tup_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$tup_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$tuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$tuple_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t$tuple_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$raise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t$showtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$myfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$mylocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$myfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#assert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#elif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#elifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#elifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#endif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#if\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#ifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#print\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#then\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#undef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Existential Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Existential Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL]\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANFunction Keyword Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANFunction Keyword Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL=\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Universal Context\NUL[\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Existential Context\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH*)\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH(*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT////\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Rest-of-file Comment\SOH(*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style Comment\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSSingleline C++ style Comment\SOH.<\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTermination Metrics Context\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULQ`\\s*[A-Za-z\\xc0-\\xd6\\xd8-\\xf6\\xf8-\\xff_][A-Za-z\\xc0-\\xd6\\xd8-\\xf6\\xf8-\\xff0-9_']*\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabsprop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babst0ype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabstype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabsview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fabsviewt0ype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vabsviewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tabsvt0ype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babsvtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclassdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdataprop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatasort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatatype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdataview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdataviewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdatavtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmacdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmacrodef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnonfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apostfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apropdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asortdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstacst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstadef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astaload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstavar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymintr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atkindef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aviewdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vviewtypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvtypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithprop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwithviewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twithvtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcastfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfnx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timplement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimplmnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTllam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpraxi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTprfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprfun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprimplement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprimplmnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANFunction Keyword Context\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#assert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#elif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#elifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#elifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#endif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#if\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#ifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#print\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#then\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#undef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$arrpsz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$arrptrsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$delay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$effmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_exn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_ntm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f$effmask_wrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$extkind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$extval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$extype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO$extype_struct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$ldelay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$list_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$list_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$lst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$lst_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$lst_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$myfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$myfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$mylocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$raise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$rec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$rec_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$rec_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$record\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t$record_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n$record_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t$showtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$tup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$tup_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$tup_vt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$tuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$tuple_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t$tuple_vt\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULM[A-Za-z\\xc0-\\xd6\\xd8-\\xf6\\xf8-\\xff_][A-Za-z\\xc0-\\xd6\\xd8-\\xf6\\xf8-\\xff0-9_']*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4~?0[xX][0-9A-Fa-f_]+\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULS~?[0-9][0-9_]*((\\.([0-9][0-9_]*)?([eE][-+]?[0-9][0-9_]*)?)|([eE][-+]?[0-9][0-9_]*))\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO~?[0-9][0-9_]*\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Rest-of-file Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Rest-of-file Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSSingleline C++ style Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSSingleline C++ style Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTermination Metrics Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTermination Metrics Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH>.\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Universal Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Universal Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXATS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"Kiwamu Okabe (kiwamu@debian.or.jp)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.dats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.sats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.hats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
