{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Email.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/email.xml and 'make bootstrap'.
module Skylighting.Syntax.Email (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Email.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\temail.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fheader-names\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBAuthentication-Results:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBcc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComments:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Content-Description:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Content-Disposition:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBContent-Transfer-Encoding:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rContent-Type:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDate:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDelivered-To:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDKIM-Signature:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nErrors-To:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFrom:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIn-Reply-To:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tKeywords:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLines:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMessage-Id:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rList-Archive:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bList-Id:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nList-Help:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nList-Post:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1List-Unsubscribe:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIList-Subscribe:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMIME-Version:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOrganization:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPrecedence:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tReceived:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rReceived-SPF:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vReferences:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vResent-Bcc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nResent-Cc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fResent-Date:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fResent-From:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Resent-Message-Id:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fReturn-Path:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEResent-Reply-To:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOResent-Sender:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nResent-To:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tReply-To:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSender:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubject:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSupersedes:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTo:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUser-Agent:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbody-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbody-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS--[0-9a-zA-Z._=-]{10,}(--)?$\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcomment-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcomment-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcomment-context\NUL)\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vquoted-pair\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubject:\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOheader-subject\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBauthentication-results:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbcc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomments:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4content-description:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4content-disposition:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcontent-transfer-encoding:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcontent-type:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdate:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdelivered-to:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdkim-signature:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nerrors-to:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfrom:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fin-reply-to:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tkeywords:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlines:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlist-archive:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlist-help:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blist-id:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlist-post:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlist-subscribe:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1list-unsubscribe:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmessage-id:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmime-version:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rorganization:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprecedence:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rreceived-spf:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treceived:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreferences:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treply-to:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vresent-bcc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresent-cc:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fresent-date:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fresent-from:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2resent-message-id:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEresent-reply-to:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresent-sender:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresent-to:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\freturn-path:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asender:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsubject:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsupersedes:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXto:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vuser-agent:\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMheader-structured-content\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE[0-9a-zA-Z-]+:\\s\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOheader-content\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbody-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOheader-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOheader-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbody-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMheader-structured-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMheader-structured-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring-context\NUL(\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcomment-context\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#<?[a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+>?\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbody-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOheader-subject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOheader-subject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring-context\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbody-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vquoted-pair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vquoted-pair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\\\[\\x00-\\x7F]\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring-context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vquoted-pair\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USVolker Krause (vkrause@kde.org)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.eml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*.email\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.emlx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.mbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.mbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader"
