{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for SQL (MySQL).
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/sql-mysql.xml and 'make bootstrap'.
module Skylighting.Syntax.SqlMysql (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for SQL (MySQL).
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsql-mysql.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSqlMysql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolFlow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKELSEIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\148\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASCII\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBIT_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECHARACTER_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCHAR_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCOALESCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCONCAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCONCAT_WS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCONV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXELT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEXPORT_SET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIELD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFIND_IN_SET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINSTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLEFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLOAD_FILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMAKE_SET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOCT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOCTET_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPOSITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQUOTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREPLACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREVERSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRIGHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSOUNDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSPACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSUBSTRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISUBSTRING_INDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTACOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTASIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTATAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQATAN2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCEILING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEGREES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEXP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGREATEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLEAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOG10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOG2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRADIANS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQROUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSQRT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCURDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_DATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CURRENT_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCURTIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATE_ADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDATE_FORMAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATE_SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDAYNAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDAYOFMONTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDAYOFWEEK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDAYOFYEAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTRACT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFROM_DAYS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFROM_UNIXTIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHOUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMINUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMONTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMONTHNAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPERIOD_ADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPERIOD_DIFF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aQUARTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSECOND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSEC_TO_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSUBDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSYSDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTIME_FORMAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTIME_TO_SEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTO_DAYS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUNIX_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWEEK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWEEKDAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYEAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bYEARWEEK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONVERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAES_DECRYPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAES_ENCRYPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBENCHMARK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBIT_COUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCONNECTION_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATABASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDECODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDES_DECRYPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDES_ENCRYPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENCODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aENCRYPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFORMAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFOUND_ROWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGET_LOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINET_ATON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINET_NTOA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIS_FREE_LOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLAST_INSERT_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMASTER_POS_WAIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMD5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPASSWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRELEASE_LOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSESSION_USER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSHA1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSYSTEM_USER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTUSER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAVG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBIT_AND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBIT_OR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTDDEV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\136\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKACCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aANALYZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXASC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAUTO_INCREMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBDB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBERKELEYDB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBOTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCASCADE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCHARSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCOLUMN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOLUMNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCONSTRAINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCREATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCROSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_DATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CURRENT_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATABASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDATABASES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDAY_HOUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDAY_MINUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDAY_SECOND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDECLARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFAULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDELAYED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDELETE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDESC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDESCRIBE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDISTINCT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDISTINCTROW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDROP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bENCLOSED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aESCAPED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXISTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPLAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFIELDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFOREIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFULLTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFUNCTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGRANT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGROUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHAVING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHIGH_PRIORITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIGNORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINNER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINNODB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJOIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXKEY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTKEYS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTKILL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLEADING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLEFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLINES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLOW_PRIORITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMASTER_SERVER_ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMATCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMRG_MYISAM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNATIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNATURAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNUMERIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOPTIMIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOPTIONALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQORDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOUTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOUTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPARTIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPRECISION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIMARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPRIVILEGES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPURGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREFERENCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREGEXP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRENAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREPLACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREQUIRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRESTRICT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRETURNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREVOKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRIGHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRLIKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSELECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSHOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSONAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSQL_BIG_RESULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SQL_CALC_FOUND_ROWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL_SMALL_RESULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSTARTING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSTRAIGHT_JOIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSTRIPED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTABLES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTERMINATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRAILING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRUNCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNIQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUNSIGNED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUPDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUSAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXUSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUSER_RESOURCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUSING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVALUES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVARYING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHERE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nYEAR_MONTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bZEROFILL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBETWEEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLIKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBINARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCHARACTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTENUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGBLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMEDIUMBLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMEDIUMTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTINYBLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTINYTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVARBINARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVARCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBIGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBOOL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDECIMAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOUBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIXED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLONG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMEDIUMINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMIDDLEINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNUMERIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTINYINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSERIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSMALLINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATETIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYEAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SO\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\SO\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSET(?=\\s*\\()\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCHARACTER SET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\136\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanalyze\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOauto_increment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nberkeleydb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acascade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acharset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcolumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acolumns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconstraint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcross\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1current_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdatabases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bday_hour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nday_minute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nday_second\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adelayed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdesc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdescribe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdistinctrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\benclosed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aescaped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexplain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfields\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfulltext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgrant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhigh_priority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKignore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinnodb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aleading\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flow_priority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmaster_server_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmrg_myisam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\noptionally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQouter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoutfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apartial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprimary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprivileges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpurge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areturns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrevoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrlike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsoname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsql_big_result\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sql_calc_found_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsql_small_result\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstarting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstraight_join\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astriped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nterminated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btrailing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuser_resources\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nyear_month\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzerofill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abetween\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*+-/<=>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH!=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH~=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH^=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH..\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX&:\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\148\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadddate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vaes_decrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vaes_encrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXavg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbenchmark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abit_and\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbit_count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbit_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbit_or\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchar_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcharacter_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconcat_ws\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconnection_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconvert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1current_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdate_add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdate_format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdate_sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adayname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndayofmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdayofweek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdayofyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adegrees\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdes_decrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdes_encrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXelt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aencrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexport_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfind_in_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfound_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfrom_days\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfrom_unixtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget_lock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgreatest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinet_aton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinet_ntoa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fis_free_lock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlast_insert_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tload_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlog2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQltrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmake_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImaster_pos_wait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmd5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmonthname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\foctet_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nperiod_add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vperiod_diff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aquarter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aradians\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frelease_lock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsec_to_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsecond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsession_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asoundex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstddev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asubdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsubstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsubstring_index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsystem_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtime_format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtime_to_sec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_days\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQucase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunix_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTweek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aweekday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\byearweek\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbigint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatetime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfixed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmediumblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmediumint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmediumtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmiddleint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmallint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btinyblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atinyint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btinytext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvarbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULO%(?:bulk_(?:exceptions|rowcount)|found|isopen|notfound|rowcount|rowtype|type)\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString2\NUL`\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTName\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@@?[^@ \\t\\r\\n]\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL.\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#Shane Wright (me@shanewright.co.uk)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.sql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.SQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.DDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
