{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Troff Mandoc.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/mandoc.xml and 'make bootstrap'.
module Skylighting.Syntax.Mandoc (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Troff Mandoc.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmandoc.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nformatting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bheadings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKothers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tparagraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDetectDirective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDetectDirective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTP\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXSM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDT\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDetectDirective\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDirective\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODetectComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTroff Mandoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDetectDirective\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDetectOthers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL0Matthew Woehlke (mw_triad@users.sourceforge.net)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.1m\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.3x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.tmac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
