{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for GLSL.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/glsl.xml and 'make bootstrap'.
module Skylighting.Syntax.Glsl (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for GLSL.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglsl.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGlsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adiscard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsubroutine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlayout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinvariant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdlib\NUL\NUL\NUL\NUL\NUL\NUL\ETX[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQacosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglActiveShaderProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglActiveTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOatomicCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ratomicCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterAnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKatomicCounterCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNatomicCounterDecrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKatomicCounterExchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNatomicCounterIncrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIatomicCounterOr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKatomicCounterSubtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicAnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOatomicCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOatomicExchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\batomicOr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglAttachShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglBeginConditionalRender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBeginQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBeginQueryIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglBeginTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glBindAttribLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBindBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglBindBufferBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindBuffersBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindBuffersRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglBindFragDataLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglBindFragDataLocationIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindImageTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBindImageTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglBindProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglBindSampler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglBindSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglBindTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglBindTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindTextureUnit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglBindTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindVertexArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindVertexBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBindVertexBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbitCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbitfieldExtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObitfieldInsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbitfieldReverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBlendColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglBlendEquation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglBlendEquationi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglBlendEquationSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglBlendEquationSeparatei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglBlendFunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBlendFunci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBlendFuncSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glBlendFuncSeparatei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBlitFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglBlitNamedFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglBufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglCheckFramebufferStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCheckNamedFramebufferStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglClampColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglClear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglClearBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glClearBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearBufferfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearBufferfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearBufferiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glClearBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglClearBufferuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglClearColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglClearDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglClearDepthf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglClearNamedBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedFramebufferfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedFramebufferfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedFramebufferiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglClearNamedFramebufferuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglClearStencil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glClearTexSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglClientWaitSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglClipControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglColorMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglColorMaski\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCompileShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCompressedTexImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCompressedTexImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCompressedTexImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglCompressedTexSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglCompressedTexSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglCompressedTexSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCompressedTextureSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCompressedTextureSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCompressedTextureSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glCopyImageSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglCopyNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCopyTexImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCopyTexImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyTexSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyTexSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyTexSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglCopyTextureSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglCopyTextureSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglCopyTextureSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCreateBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glCreateFramebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCreateProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglCreateProgramPipelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCreateQueries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglCreateRenderbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCreateSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglCreateShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglCreateShaderProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCreateShaderProgramv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCreateTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglCreateTransformFeedbacks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glCreateVertexArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcross\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglCullFace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglDebugMessageCallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglDebugMessageControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDebugMessageInsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adegrees\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglDeleteBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDeleteFramebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglDeleteProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglDeleteProgramPipelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglDeleteQueries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglDeleteRenderbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglDeleteSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglDeleteShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDeleteSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglDeleteTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglDeleteTransformFeedbacks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDeleteVertexArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglDepthFunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglDepthMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDepthRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glDepthRangeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glDepthRangeArrayv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglDepthRangef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glDepthRangeIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglDetachShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdeterminant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdFdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndFdxCoarse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdFdxFine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdFdy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndFdyCoarse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdFdyFine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglDisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglDisablei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglDisableVertexArrayAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglDisableVertexAttribArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glDispatchCompute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglDispatchComputeIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDrawArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDrawArraysIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglDrawArraysInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glDrawArraysInstancedBaseInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDrawBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglDrawBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglDrawElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglDrawElementsBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglDrawElementsIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglDrawElementsInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#glDrawElementsInstancedBaseInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glDrawElementsInstancedBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-glDrawElementsInstancedBaseVertexBaseInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glDrawRangeElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglDrawRangeElementsBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglDrawTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL glDrawTransformFeedbackInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglDrawTransformFeedbackStream\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&glDrawTransformFeedbackStreamInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEmitStreamVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEmitVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglEnable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglEnablei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglEnableVertexArrayAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglEnableVertexAttribArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglEndConditionalRender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEndPrimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglEndQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glEndQueryIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2EndStreamPrimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglEndTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexp2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfaceforward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglFenceSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afindLSB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afindMSB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglFinish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfloatBitsToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfloatBitsToUint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglFlush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglFlushMappedBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglFlushMappedNamedBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglFramebufferParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglFramebufferRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glFramebufferTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglFramebufferTexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglFramebufferTexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglFramebufferTexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglFramebufferTextureLayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfrexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglFrontFace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffwidthCoarse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfwidthFine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGenBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGenerateMipmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGenerateTextureMipmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGenFramebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGenProgramPipelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGenQueries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGenRenderbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGenSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGenTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGenTransformFeedbacks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGenVertexArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQglGet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL glGetActiveAtomicCounterBufferiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetActiveAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetActiveSubroutineName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetActiveSubroutineUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglGetActiveSubroutineUniformiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL glGetActiveSubroutineUniformName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetActiveUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetActiveUniformBlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetActiveUniformBlockiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetActiveUniformBlockName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetActiveUniformName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetActiveUniformsiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetAttachedShaders\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetAttribLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetBooleani_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetBooleanv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetBufferParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetBufferParameteri64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetBufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetBufferPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetCompressedTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetCompressedTextureImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglGetCompressedTextureSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetDebugMessageLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetDoublei_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetDoublev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglGetError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetFloati_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetFloatv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetFragDataIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetFragDataLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#glGetFramebufferAttachmentParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%glGetFramebufferAttachmentParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetFramebufferParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetFramebufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetGraphicsResetStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetInteger64i_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetInteger64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetIntegeri_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetIntegerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetInternalformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetInternalformati64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetInternalformativ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetMultisamplefv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglGetNamedBufferParameteri64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetNamedBufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetNamedBufferPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*glGetNamedFramebufferAttachmentParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL glGetNamedFramebufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glGetNamedRenderbufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetnCompressedTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetnTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetnUniformdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetnUniformfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetnUniformiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetnUniformuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetObjectLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetObjectPtrLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetProgramBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetProgramInfoLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetProgramInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetProgramInterfaceiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetProgramiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetProgramPipelineInfoLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetProgramPipelineiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetProgramResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetProgramResourceIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetProgramResourceiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetProgramResourceLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glGetProgramResourceLocationIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetProgramResourceName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetProgramStage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetProgramStageiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetQueryIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetQueryIndexediv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetQueryiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetQueryObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetQueryObjecti64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetQueryObjectiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetQueryObjectui64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetQueryObjectuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglGetRenderbufferParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetRenderbufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetSamplerParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetSamplerParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetSamplerParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetSamplerParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetSamplerParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetShaderInfoLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetShaderiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglGetShaderPrecisionFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetShaderSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetStringi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetSubroutineIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglGetSubroutineUniformLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglGetSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetSynciv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetTexLevelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTexLevelParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTexLevelParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetTexParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetTexParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetTexParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetTexParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetTexParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetTextureImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetTextureLevelParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetTextureLevelParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetTextureParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTextureParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetTextureParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetTextureParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetTextureSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetTransformFeedbacki64_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetTransformFeedbacki_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTransformFeedbackiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglGetTransformFeedbackVarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetUniformBlockIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetUniformdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetUniformfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetUniformIndices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetUniformiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetUniformLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetUniformSubroutine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetUniformSubroutineuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetUniformuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetVertexArrayIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetVertexArrayIndexed64iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetVertexArrayIndexediv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetVertexArrayiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetVertexAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetVertexAttribdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetVertexAttribfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetVertexAttribIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetVertexAttribIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetVertexAttribiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetVertexAttribLdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetVertexAttribPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ClipDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_CullDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_FrontFacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_GlobalInvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_HelperInvocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_InstanceID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_InvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Layer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4gl_LocalInvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_LocalInvocationIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_NumSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_NumWorkGroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_PatchVerticesIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_PointCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_PointSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_Position\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_PrimitiveID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_PrimitiveIDIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_SampleID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_SampleMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_SampleMaskIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_SamplePosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_TessCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelInner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelOuter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_VertexID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_ViewportIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_WorkGroupID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_WorkGroupSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgreaterThan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgreaterThanEqual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2groupMemoryBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglHint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicAnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3imageAtomicCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3imageAtomicExchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rimageAtomicOr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timageLoad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimageSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timageSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimageStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimulExtended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOintBitsToFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKinterpolateAtCentroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3interpolateAtOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3interpolateAtSample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglInvalidateBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglInvalidateBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglInvalidateFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL glInvalidateNamedFramebufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#glInvalidateNamedFramebufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglInvalidateSubFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glInvalidateTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglInvalidateTexSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinversesqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglIsBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsEnabled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglIsEnabledi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglIsFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisinf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisnan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glIsProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglIsQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglIsRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsSampler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglIsShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglIsSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglIsTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglIsVertexArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQldexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blessThan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlessThanEqual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglLineWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglLinkProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlog2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglLogicOp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglMapBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglMapBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglMapNamedBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglMapNamedBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatrixCompMult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmemoryBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglMemoryBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBmemoryBarrierAtomicCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3memoryBarrierBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglMemoryBarrierByRegion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2memoryBarrierImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3memoryBarrierShared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glMinSampleShading\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmodf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glMultiDrawArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglMultiDrawArraysIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glMultiDrawElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglMultiDrawElementsBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglMultiDrawElementsIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glNamedBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glNamedBufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglNamedFramebufferDrawBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglNamedFramebufferDrawBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglNamedFramebufferParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglNamedFramebufferReadBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglNamedFramebufferRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglNamedFramebufferTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglNamedFramebufferTextureLayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglNamedRenderbufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%glNamedRenderbufferStorageMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnoise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnormalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotEqual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglObjectLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglObjectPtrLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fouterProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpackDouble2x32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackHalf2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackSnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackSnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpackUnorm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackUnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackUnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglPatchParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glPatchParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glPatchParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglPauseTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglPixelStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglPixelStoref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglPixelStorei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglPointParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glPointParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glPointParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glPointParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glPointParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglPointSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglPolygonMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglPolygonOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglPopDebugGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglPrimitiveRestartIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglProgramBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglProgramUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform1fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform1i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform1iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform1uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform2i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform2iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform2uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform3i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform3iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform3uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform4f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform4i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglProgramUniformMatrix2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix2x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix2x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglProgramUniformMatrix3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix3x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix3x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglProgramUniformMatrix4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix4x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix4x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glProvokingVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglPushDebugGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglQueryCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aradians\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglReadBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglReadnPixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglReadPixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areflect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arefract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglReleaseShaderCompiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fremovedTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglRenderbufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL glRenderbufferStorageMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglResumeTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\troundEven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglSampleCoverage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglSampleMaski\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glSamplerParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glSamplerParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glSamplerParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glSamplerParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglSamplerParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglSamplerParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glSamplerParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglScissor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglScissorArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglScissorArrayv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglScissorIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glScissorIndexedv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglShaderBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglShaderSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglShaderStorageBlockBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmoothstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglStencilFunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglStencilFuncSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglStencilMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglStencilMaskSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglStencilOp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glStencilOpSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglTexBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTexBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntexelFetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtexelFetchOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglTexImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglTexImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglTexImage2DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglTexImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglTexImage3DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTexParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glTexParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTexParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTexParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexStorage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexStorage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglTexStorage2DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexStorage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglTexStorage3DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTextureBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glTextureBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureGather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3textureGatherOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4textureGatherOffsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureGrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1textureGradOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntextureLod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextureLodOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glTextureParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglTextureParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglTextureParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glTextureParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureProj\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItextureProjGrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtextureProjGradOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtextureProjLod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4textureProjLodOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1textureProjOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2textureQueryLevels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItextureQueryLod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtextureSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTextureStorage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTextureStorage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglTextureStorage2DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTextureStorage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglTextureStorage3DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglTextureView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglTransformFeedbackBufferBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglTransformFeedbackBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglTransformFeedbackVaryings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuaddCarry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuintBitsToFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fumulExtended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform1fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform1i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform1iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform1uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform2i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform2iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform2uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform3i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform3iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform3uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform4f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform4i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglUniformBlockBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUniformMatrix2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix2x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix2x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUniformMatrix3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix3x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix3x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUniformMatrix4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix4x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix4x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformSubroutines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglUniformSubroutinesuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUnmapBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUnmapNamedBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEunpackDouble2x32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunpackHalf2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunpackSnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunpackSnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunpackUnorm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunpackUnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunpackUnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUseProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUseProgramStages\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusubBorrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glValidateProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglValidateProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayAttribBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglVertexArrayAttribFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayAttribIFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayAttribLFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglVertexArrayBindingDivisor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayElementBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglVertexArrayVertexBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayVertexBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglVertexAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib1d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib1dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib1fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib1s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib1sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib2dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib2s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib2sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib3dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib3s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib3sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4bv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib4d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib4f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Nbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Niv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Nsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Nub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttrib4Nubv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttrib4Nuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttrib4Nusv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib4s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4ubv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4usv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribDivisor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glVertexAttribFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI1i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI1iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI1uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI2i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI2iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI2uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI3i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI3iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI3uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4bv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI4i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI4ubv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI4usv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribIFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglVertexAttribIPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL1d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL1dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL2dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL3dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL4d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL4dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribLFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglVertexAttribLPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglVertexBindingDivisor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglViewport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglViewportArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglViewportArrayv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glViewportIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glViewportIndexedf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glViewportIndexedfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglWaitSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\172\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_Position\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_PointSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_ClipVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_FragFacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_FragData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_SecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgl_Normal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgl_Vertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_FogColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ClipDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_PrimitiveIDIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_InvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_PrimitiveID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Layer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_ViewportIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_TessCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_PatchVerticesIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelOuter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelInner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxPatchVertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgl_in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgl_out\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxAtomicCounterBindings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxAtomicCounterBufferSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxClipDistances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_MaxClipPlanes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxCombinedAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxCombinedAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxCombinedClipAndCullDistances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxCombinedImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*gl_MaxCombinedImageUnitsAndFragmentOutputs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_MaxCombinedShaderOutputResources\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxCombinedTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!gl_MaxComputeAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxComputeAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxComputeImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxComputeTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxComputeUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxComputeWorkGroupCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxComputeWorkGroupSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxCullDistances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MaxDrawBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxFragmentAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxFragmentAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxFragmentImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxFragmentInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxFragmentUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxFragmentUniformVectors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxGeometryAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxGeometryAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxGeometryImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxGeometryInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxGeometryOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxGeometryOutputVertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxGeometryTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_MaxGeometryTotalOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxGeometryUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxImageSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_MaxImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgl_MaxInputAttachments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_MaxLights\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxPatchVertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_MaxProgramTexelOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_MaxSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_MaxTessControlAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxTessControlAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxTessControlImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL gl_MaxTessControlInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!gl_MaxTessControlOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxTessControlTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&gl_MaxTessControlTotalOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxTessControlUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(gl_MaxTessEvaluationAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxTessEvaluationAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!gl_MaxTessEvaluationImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_MaxTessEvaluationInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$gl_MaxTessEvaluationOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_MaxTessEvaluationTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_MaxTessEvaluationUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxTessGenLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_MaxTessPatchComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxTextureCoords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_MaxTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxTextureUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxTransformFeedbackBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,gl_MaxTransformFeedbackInterleavedComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_MaxVaryingComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxVaryingFloats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4gl_MaxVaryingVectors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL gl_MaxVertexAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxVertexAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxVertexAttribs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgl_MaxVertexAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_MaxVertexImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxVertexOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxVertexTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxVertexUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxVertexUniformVectors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_MaxViewports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_MinProgramTexelOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxTextureUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxTextureCoords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_MaxClipPlanes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxVaryingFloats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_ModelViewMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_ProjectionMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_ModelViewProjectionMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_TextureMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_NormalMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_ModelViewMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_ProjectionMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_ModelViewProjectionMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_TextureMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_ModelViewMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_ProjectionMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_ModelViewProjectionMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_TextureMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_ModelViewMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_ProjectionMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,gl_ModelViewProjectionMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL gl_TextureMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_NormScale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_DepthRangeParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_DepthRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_ClipPlane\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_PointParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Point\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_MaterialParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_FrontMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_BackMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_LightSourceParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_LightSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_LightModelParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_LightModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_LightModelProducts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_FrontLightModelProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_BackLightModelProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_LightProducts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4gl_FrontLightProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_BackLightProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_TextureEnvColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_FogParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgl_Fog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_FrontColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_BackColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgl_FrontSecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_BackSecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_TexCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_FogFragCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_SecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btypequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlowp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amediump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQhighp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprecise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnoperspective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsmooth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcentroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trow_major\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpacked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstd140\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstd430\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxfb_buffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxfb_offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxfb_stride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1origin_upper_left\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4pixel_center_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4early_fragment_tests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlines_adjacency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3triangles_adjacency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nline_strip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtriangle_strip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmax_vertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinvocations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstream\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisolines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npoint_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\requal_spacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBfractional_even_spacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNfractional_odd_spacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXccw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoherent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twriteonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\160\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmat2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmat3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmat4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat2x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat2x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat2x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat3x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat3x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat3x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat4x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat4x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat4x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmat2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmat3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmat4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat2x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat2x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat2x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat3x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat3x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat3x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat4x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat4x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat4x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQivec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQivec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQivec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsampler1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsampler1DShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsampler1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimage1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4sampler1DArrayShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsampler2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsampler2DShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsampler2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtexture2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimage2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4sampler2DArrayShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsampler2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtexture2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timage2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsampler2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtexture2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimage2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsampler2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtexture2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimage2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sampler2DRectShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsampler3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsamplerCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timageCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1samplerCubeShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsamplerCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextureCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsamplerCubeArrayShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsamplerBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimageBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubpassInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsubpassInputMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisampler1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biimage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisampler1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIitexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\riimage1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisampler2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biimage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisampler2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIitexture2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\riimage2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fisampler2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fitexture2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niimage2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1isampler2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1itexture2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIiimage2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisampler2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOitexture2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fiimage2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisampler3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biimage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fisamplerCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fitextureCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niimageCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1isamplerCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1itextureCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIiimageCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisamplerBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOitextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fiimageBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\risubpassInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisubpassInputMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusampler1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buimage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusampler1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIutexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruimage1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusampler2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buimage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusampler2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIutexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruimage2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fusampler2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\futexture2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuimage2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1usampler2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1utexture2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuimage2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOusampler2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOutexture2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuimage2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusampler3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buimage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fusamplerCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\futextureCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuimageCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1usamplerCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1utextureCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuimageCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOusamplerBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOutextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuimageBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vatomic_uint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rusubpassInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusubpassInputMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asampler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsamplerShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b[_\\w][_\\w\\d]*(?=[\\s]*)\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adiscard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinvariant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlayout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsubroutine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\159\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vatomic_uint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmat2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat2x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat2x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat2x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmat3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat3x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat3x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat3x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmat4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat4x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat4x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\admat4x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biimage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\riimage1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biimage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\riimage2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niimage2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIiimage2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fiimage2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biimage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fiimageBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niimageCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIiimageCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimage1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimage2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timage2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimage2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimage2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimageBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timageCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisampler1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisampler1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisampler2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisampler2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fisampler2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1isampler2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisampler2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisampler3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisamplerBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fisamplerCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1isamplerCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\risubpassInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisubpassInputMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIitexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIitexture2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fitexture2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1itexture2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOitexture2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOitextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fitextureCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1itextureCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQivec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQivec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQivec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmat2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat2x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat2x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat2x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmat3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat3x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat3x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat3x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmat4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat4x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat4x3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmat4x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asampler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsampler1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsampler1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4sampler1DArrayShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsampler1DShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsampler2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsampler2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4sampler2DArrayShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsampler2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsampler2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsampler2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sampler2DRectShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsampler2DShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsampler3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsamplerBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsamplerCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsamplerCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsamplerCubeArrayShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1samplerCubeShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsamplerShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubpassInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsubpassInputMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtexture2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtexture2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtexture2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtexture2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextureCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buimage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruimage1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buimage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruimage2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuimage2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuimage2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuimage2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buimage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuimageBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuimageCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuimageCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusampler1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusampler1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusampler2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusampler2DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fusampler2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1usampler2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOusampler2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusampler3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOusamplerBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fusamplerCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1usamplerCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rusubpassInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusubpassInputMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIutexture1DArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\futexture2DMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1utexture2DMSArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOutexture2DRect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOutextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\futextureCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1utextureCubeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvec2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvec3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvec4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXccw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcentroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoherent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4early_fragment_tests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\requal_spacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBfractional_even_spacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNfractional_odd_spacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQhighp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinvocations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisolines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nline_strip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlines_adjacency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlowp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmax_vertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amediump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnoperspective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1origin_upper_left\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpacked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4pixel_center_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npoint_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprecise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trow_major\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsmooth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstd140\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstd430\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstream\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtriangle_strip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3triangles_adjacency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twriteonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxfb_buffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxfb_offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxfb_stride\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEmitStreamVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEmitVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEndPrimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2EndStreamPrimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQacosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicAnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOatomicCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ratomicCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterAnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKatomicCounterCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNatomicCounterDecrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKatomicCounterExchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNatomicCounterIncrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIatomicCounterOr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKatomicCounterSubtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEatomicCounterXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOatomicExchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\batomicOr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomicXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbitCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbitfieldExtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObitfieldInsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbitfieldReverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcross\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdFdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndFdxCoarse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdFdxFine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdFdy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndFdyCoarse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdFdyFine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adegrees\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdeterminant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexp2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfaceforward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afindLSB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afindMSB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfloatBitsToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfloatBitsToUint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfrexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffwidthCoarse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfwidthFine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglActiveShaderProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglActiveTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglAttachShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglBeginConditionalRender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBeginQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBeginQueryIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglBeginTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glBindAttribLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBindBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglBindBufferBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindBuffersBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindBuffersRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglBindFragDataLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglBindFragDataLocationIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindImageTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBindImageTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglBindProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglBindSampler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglBindSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglBindTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindTextureUnit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglBindTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglBindTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBindVertexArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glBindVertexBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBindVertexBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBlendColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglBlendEquation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglBlendEquationSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglBlendEquationSeparatei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglBlendEquationi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglBlendFunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glBlendFuncSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glBlendFuncSeparatei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBlendFunci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glBlitFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglBlitNamedFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglBufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglCheckFramebufferStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCheckNamedFramebufferStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglClampColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglClear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglClearBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glClearBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glClearBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearBufferfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearBufferfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearBufferiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglClearBufferuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglClearColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglClearDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglClearDepthf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglClearNamedBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedFramebufferfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedFramebufferfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglClearNamedFramebufferiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglClearNamedFramebufferuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglClearStencil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglClearTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glClearTexSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglClientWaitSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglClipControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglColorMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglColorMaski\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCompileShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCompressedTexImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCompressedTexImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCompressedTexImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglCompressedTexSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglCompressedTexSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglCompressedTexSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCompressedTextureSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCompressedTextureSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglCompressedTextureSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glCopyImageSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglCopyNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCopyTexImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCopyTexImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyTexSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyTexSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glCopyTexSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglCopyTextureSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglCopyTextureSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglCopyTextureSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCreateBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glCreateFramebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCreateProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglCreateProgramPipelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglCreateQueries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglCreateRenderbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCreateSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglCreateShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglCreateShaderProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglCreateShaderProgramv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglCreateTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglCreateTransformFeedbacks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glCreateVertexArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglCullFace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglDebugMessageCallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglDebugMessageControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDebugMessageInsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglDeleteBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDeleteFramebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglDeleteProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglDeleteProgramPipelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglDeleteQueries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglDeleteRenderbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglDeleteSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglDeleteShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDeleteSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglDeleteTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglDeleteTransformFeedbacks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDeleteVertexArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglDepthFunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglDepthMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDepthRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glDepthRangeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glDepthRangeArrayv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glDepthRangeIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglDepthRangef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglDetachShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglDisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglDisableVertexArrayAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglDisableVertexAttribArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglDisablei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glDispatchCompute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglDispatchComputeIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDrawArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glDrawArraysIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglDrawArraysInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glDrawArraysInstancedBaseInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglDrawBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglDrawBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglDrawElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglDrawElementsBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglDrawElementsIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglDrawElementsInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL#glDrawElementsInstancedBaseInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glDrawElementsInstancedBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL-glDrawElementsInstancedBaseVertexBaseInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glDrawRangeElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglDrawRangeElementsBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglDrawTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL glDrawTransformFeedbackInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglDrawTransformFeedbackStream\NUL\NUL\NUL\NUL\NUL\NUL\NUL&glDrawTransformFeedbackStreamInstanced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglEnable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglEnableVertexArrayAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglEnableVertexAttribArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglEnablei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglEndConditionalRender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglEndQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glEndQueryIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglEndTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglFenceSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglFinish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglFlush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglFlushMappedBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglFlushMappedNamedBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglFramebufferParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglFramebufferRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glFramebufferTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglFramebufferTexture1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglFramebufferTexture2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglFramebufferTexture3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglFramebufferTextureLayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglFrontFace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGenBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGenFramebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGenProgramPipelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGenQueries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGenRenderbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGenSamplers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGenTextures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGenTransformFeedbacks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGenVertexArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGenerateMipmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGenerateTextureMipmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQglGet\NUL\NUL\NUL\NUL\NUL\NUL\NUL glGetActiveAtomicCounterBufferiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetActiveAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetActiveSubroutineName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetActiveSubroutineUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL glGetActiveSubroutineUniformName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglGetActiveSubroutineUniformiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetActiveUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetActiveUniformBlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetActiveUniformBlockName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetActiveUniformBlockiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetActiveUniformName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetActiveUniformsiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetAttachedShaders\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetAttribLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetBooleani_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetBooleanv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetBufferParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetBufferParameteri64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetBufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetBufferPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetCompressedTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetCompressedTextureImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglGetCompressedTextureSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetDebugMessageLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetDoublei_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetDoublev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglGetError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetFloati_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetFloatv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetFragDataIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetFragDataLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL#glGetFramebufferAttachmentParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL%glGetFramebufferAttachmentParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetFramebufferParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetFramebufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetGraphicsResetStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetInteger64i_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetInteger64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetIntegeri_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetIntegerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetInternalformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetInternalformati64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetInternalformativ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetMultisamplefv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglGetNamedBufferParameteri64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetNamedBufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetNamedBufferPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL*glGetNamedFramebufferAttachmentParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL glGetNamedFramebufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glGetNamedRenderbufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetObjectLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetObjectPtrLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetProgramBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetProgramInfoLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetProgramInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetProgramInterfaceiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetProgramPipelineInfoLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetProgramPipelineiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetProgramResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetProgramResourceIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetProgramResourceLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL!glGetProgramResourceLocationIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetProgramResourceName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetProgramResourceiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetProgramStage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetProgramStageiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetProgramiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetQueryIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetQueryIndexediv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetQueryObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetQueryObjecti64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetQueryObjectiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetQueryObjectui64v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetQueryObjectuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetQueryiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglGetRenderbufferParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetRenderbufferParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetSamplerParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetSamplerParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetSamplerParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetSamplerParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetSamplerParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetShaderInfoLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglGetShaderPrecisionFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetShaderSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetShaderiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetStringi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetSubroutineIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglGetSubroutineUniformLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglGetSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglGetSynciv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglGetTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetTexLevelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTexLevelParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTexLevelParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetTexParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetTexParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetTexParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetTexParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetTexParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetTextureImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetTextureLevelParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglGetTextureLevelParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTextureParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetTextureParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetTextureParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetTextureParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetTextureSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglGetTransformFeedbackVarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetTransformFeedbacki64_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetTransformFeedbacki_v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetTransformFeedbackiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglGetUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetUniformBlockIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetUniformIndices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetUniformLocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglGetUniformSubroutine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetUniformSubroutineuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetUniformdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetUniformfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetUniformiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetUniformuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglGetVertexArrayIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglGetVertexArrayIndexed64iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetVertexArrayIndexediv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glGetVertexArrayiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glGetVertexAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetVertexAttribIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglGetVertexAttribIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glGetVertexAttribLdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglGetVertexAttribPointerv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetVertexAttribdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetVertexAttribfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glGetVertexAttribiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglGetnCompressedTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglGetnTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetnUniformdv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetnUniformfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglGetnUniformiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglGetnUniformuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglHint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglInvalidateBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglInvalidateBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglInvalidateFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL glInvalidateNamedFramebufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL#glInvalidateNamedFramebufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglInvalidateSubFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glInvalidateTexImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglInvalidateTexSubImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglIsBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsEnabled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglIsEnabledi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglIsFramebuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glIsProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglIsQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglIsRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsSampler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglIsShader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglIsSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglIsTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglIsTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglIsVertexArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglLineWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglLinkProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglLogicOp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglMapBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglMapBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglMapNamedBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglMapNamedBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglMemoryBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglMemoryBarrierByRegion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glMinSampleShading\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glMultiDrawArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglMultiDrawArraysIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glMultiDrawElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglMultiDrawElementsBaseVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglMultiDrawElementsIndirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glNamedBufferData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glNamedBufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glNamedBufferSubData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglNamedFramebufferDrawBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglNamedFramebufferDrawBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglNamedFramebufferParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSglNamedFramebufferReadBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglNamedFramebufferRenderbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglNamedFramebufferTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglNamedFramebufferTextureLayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglNamedRenderbufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL%glNamedRenderbufferStorageMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglObjectLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglObjectPtrLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglPatchParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glPatchParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glPatchParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANglPauseTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglPixelStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglPixelStoref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglPixelStorei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglPointParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glPointParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glPointParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glPointParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glPointParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglPointSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglPolygonMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglPolygonOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglPopDebugGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglPrimitiveRestartIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglProgramBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglProgramUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform1fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform1i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform1iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform1uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform2i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform2iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform2uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform3i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform3iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform3uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform4f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glProgramUniform4i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glProgramUniform4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glProgramUniform4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglProgramUniformMatrix2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix2x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix2x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglProgramUniformMatrix3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix3x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix3x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglProgramUniformMatrix4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix4x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglProgramUniformMatrix4x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glProvokingVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglPushDebugGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglQueryCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglReadBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglReadPixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglReadnPixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglReleaseShaderCompiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglRenderbufferStorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL glRenderbufferStorageMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglResumeTransformFeedback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglSampleCoverage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglSampleMaski\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glSamplerParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglSamplerParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglSamplerParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glSamplerParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glSamplerParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glSamplerParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glSamplerParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglScissor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglScissorArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglScissorArrayv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglScissorIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glScissorIndexedv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglShaderBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglShaderSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglShaderStorageBlockBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglStencilFunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglStencilFuncSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglStencilMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglStencilMaskSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglStencilOp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glStencilOpSeparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglTexBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTexBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglTexImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglTexImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglTexImage2DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglTexImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglTexImage3DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glTexParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTexParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTexParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTexParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexStorage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexStorage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglTexStorage2DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglTexStorage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglTexStorage3DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTexSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglTextureBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglTextureBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glTextureBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglTextureParameterIiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglTextureParameterIuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureParameterf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glTextureParameterfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureParameteri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glTextureParameteriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTextureStorage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTextureStorage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglTextureStorage2DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glTextureStorage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglTextureStorage3DMultisample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureSubImage1D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureSubImage2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glTextureSubImage3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglTextureView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSglTransformFeedbackBufferBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSglTransformFeedbackBufferRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglTransformFeedbackVaryings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglUniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform1fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform1i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform1iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform1uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform2i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform2iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform2uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform3i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform3iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform3uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform4f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglUniform4i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUniform4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUniform4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglUniformBlockBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUniformMatrix2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix2x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix2x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUniformMatrix3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix3x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix3x4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUniformMatrix4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix4x2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformMatrix4x3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glUniformSubroutines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBglUniformSubroutinesuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rglUnmapBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUnmapNamedBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fglUseProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glUseProgramStages\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glValidateProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglValidateProgramPipeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayAttribBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglVertexArrayAttribFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayAttribIFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayAttribLFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCglVertexArrayBindingDivisor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayElementBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMglVertexArrayVertexBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBglVertexArrayVertexBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOglVertexAttrib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib1d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib1dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib1fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib1s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib1sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib2dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib2fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib2s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib2sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib3dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib3fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib3s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib3sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Nbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Niv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Nsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4Nub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttrib4Nubv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttrib4Nuiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttrib4Nusv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4bv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib4d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib4f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4fv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglVertexAttrib4s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttrib4sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4ubv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttrib4usv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribDivisor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4glVertexAttribFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI1i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI1iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI1uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI2i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI2iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI2uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI3i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI3iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI3uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4bv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribI4i\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4iv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4sv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI4ubv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribI4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI4uiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glVertexAttribI4usv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribIFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglVertexAttribIPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL1d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL1dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL2dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL3dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glVertexAttribL4d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribL4dv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribLFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglVertexAttribLPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP1ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP2ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP3ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glVertexAttribP4ui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKglVertexAttribPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNglVertexBindingDivisor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglViewport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIglViewportArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEglViewportArrayv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1glViewportIndexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2glViewportIndexedf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3glViewportIndexedfv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglWaitSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ClipDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_CullDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_FrontFacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_GlobalInvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_HelperInvocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_InstanceID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_InvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Layer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4gl_LocalInvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_LocalInvocationIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_NumSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_NumWorkGroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_PatchVerticesIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_PointCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_PointSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_Position\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_PrimitiveID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_PrimitiveIDIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_SampleID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_SampleMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_SampleMaskIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_SamplePosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_TessCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelInner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelOuter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_VertexID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_ViewportIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_WorkGroupID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_WorkGroupSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgreaterThan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgreaterThanEqual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2groupMemoryBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicAnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3imageAtomicCompSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3imageAtomicExchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rimageAtomicOr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimageAtomicXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timageLoad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimageSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timageSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimageStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimulExtended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOintBitsToFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKinterpolateAtCentroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3interpolateAtOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3interpolateAtSample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinversesqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisinf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisnan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQldexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blessThan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlessThanEqual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlog2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatrixCompMult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmemoryBarrier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBmemoryBarrierAtomicCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3memoryBarrierBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2memoryBarrierImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3memoryBarrierShared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmodf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnoise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoise4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnormalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotEqual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fouterProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpackDouble2x32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackHalf2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackSnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackSnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpackUnorm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackUnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackUnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aradians\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areflect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arefract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fremovedTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\troundEven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmoothstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntexelFetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtexelFetchOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureGather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3textureGatherOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4textureGatherOffsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureGrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1textureGradOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntextureLod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextureLodOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureProj\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItextureProjGrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtextureProjGradOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtextureProjLod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4textureProjLodOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1textureProjOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2textureQueryLevels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItextureQueryLod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtextureSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtextureSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuaddCarry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuintBitsToFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fumulExtended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEunpackDouble2x32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunpackHalf2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunpackSnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunpackSnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunpackUnorm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunpackUnorm2x16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOunpackUnorm4x8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nusubBorrow\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\164\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_BackColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_BackLightModelProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_BackLightProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_BackMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_BackSecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ClipDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_ClipPlane\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_ClipVertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_DepthRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_DepthRangeParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_EyePlaneT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgl_Fog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_FogColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_FogFragCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_FogParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_FragData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_FragDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_FragFacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_FrontColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_FrontLightModelProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4gl_FrontLightProduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_FrontMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgl_FrontSecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_InvocationID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Layer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_LightModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_LightModelParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_LightModelProducts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_LightProducts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_LightSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_LightSourceParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgl_MaterialParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxAtomicCounterBindings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxAtomicCounterBufferSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxClipDistances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_MaxClipPlanes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxCombinedAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxCombinedAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxCombinedClipAndCullDistances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxCombinedImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL*gl_MaxCombinedImageUnitsAndFragmentOutputs\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_MaxCombinedShaderOutputResources\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxCombinedTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL!gl_MaxComputeAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxComputeAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxComputeImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxComputeTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxComputeUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxComputeWorkGroupCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxComputeWorkGroupSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxCullDistances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MaxDrawBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxFragmentAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxFragmentAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxFragmentImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxFragmentInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxFragmentUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxFragmentUniformVectors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxGeometryAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxGeometryAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_MaxGeometryImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxGeometryInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxGeometryOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxGeometryOutputVertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxGeometryTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_MaxGeometryTotalOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxGeometryUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxImageSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_MaxImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgl_MaxInputAttachments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_MaxLights\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxPatchVertices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_MaxProgramTexelOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgl_MaxSamples\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_MaxTessControlAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USgl_MaxTessControlAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxTessControlImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL gl_MaxTessControlInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL!gl_MaxTessControlOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxTessControlTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL&gl_MaxTessControlTotalOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxTessControlUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL(gl_MaxTessEvaluationAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_MaxTessEvaluationAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL!gl_MaxTessEvaluationImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_MaxTessEvaluationInputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL$gl_MaxTessEvaluationOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_MaxTessEvaluationTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_MaxTessEvaluationUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxTessGenLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_MaxTessPatchComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxTextureCoords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_MaxTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_MaxTextureUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSgl_MaxTransformFeedbackBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL,gl_MaxTransformFeedbackInterleavedComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_MaxVaryingComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxVaryingFloats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4gl_MaxVaryingVectors\NUL\NUL\NUL\NUL\NUL\NUL\NUL gl_MaxVertexAtomicCounterBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxVertexAtomicCounters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_MaxVertexAttribs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgl_MaxVertexAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_MaxVertexImageUniforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_MaxVertexOutputComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxVertexTextureImageUnits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSgl_MaxVertexUniformComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_MaxVertexUniformVectors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_MaxViewports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgl_MinProgramTexelOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_ModelViewMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_ModelViewMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"gl_ModelViewMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgl_ModelViewMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_ModelViewProjectionMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_ModelViewProjectionMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL,gl_ModelViewProjectionMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL%gl_ModelViewProjectionMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_MultiTexCoord7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_NormScale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgl_Normal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_NormalMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgl_ObjectPlaneT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_PatchVerticesIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgl_Point\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_PointParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_PointSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_Position\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgl_PrimitiveID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_PrimitiveIDIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3gl_ProjectionMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBgl_ProjectionMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL#gl_ProjectionMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgl_ProjectionMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_SecondaryColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgl_TessCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelInner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1gl_TessLevelOuter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgl_TexCoord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2gl_TextureEnvColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_TextureMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgl_TextureMatrixInverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL gl_TextureMatrixInverseTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMgl_TextureMatrixTranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgl_Vertex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgl_ViewportIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgl_in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgl_out\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\b[_\\w][_\\w\\d]*(?=[\\s]*[(])\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMember\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK!%&()*+,-/:;<=>?[]^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#Oliver Richers (o.richers@tu-bs.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.glsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.vert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.vs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.frag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.fs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.geom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.gs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.tcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.tes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
