{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Zsh.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/zsh.xml and 'make bootstrap'.
module Skylighting.Syntax.Zsh (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Zsh.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsh.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NULa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautoload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abindkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbye\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomparguments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcompcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcompdescribe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcompfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncompgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcompquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomptags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomptry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncompvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdirs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdisown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKechotc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKechoti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aemulate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjobs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnocorrect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrehash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsched\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKttyctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKulimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunhash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzcompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzmodload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nzparseopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzprof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzpty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vzregexparse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTztcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbuiltins_var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgetln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypeset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funixcommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funixcommands\NUL\NUL\NUL\NUL\NUL\NUL\SOH;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL:\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANVarNameDispatchModifiers\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSRecursiveAlternatePatternValue\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindStringDQPattern\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRecursiveAlternateValue\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AlternateValuePrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AlternateValuePrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH^^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*+-=?^|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH:=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceSubst\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1&APQaceghlpqrstux\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarBraceModifiers\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVarSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegularAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssignArrayKey\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAssignArrayBackq\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a&();<>|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAssignArrayBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAssignArrayBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssignArrayKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssignArrayKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>>|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>>!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT>>&|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT>>&!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>>(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\SOH>>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH>|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH>!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>&|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>&!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH>&\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\SOH>(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH<(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<<(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<<<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringRedirection\SOH<<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHereDoc\SOH<&\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\SOH<>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBaseN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBaseN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[0-9a-zA-Z@_]+\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEscapeMaybeBraceExpansion\NUL\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL$\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBraceExpansionVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBraceExpansionVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBraceExpansionVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinGetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinGetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsOpt\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsOpt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsOpt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BuiltinGetoptsOpt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BuiltinGetoptsOpt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BuiltinGetoptsOpt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsVar\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNormalOptionMaybeBraceExpansion\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r%./0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBuiltinLet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBuiltinLet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetArgs\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BuiltinLetArgsNumber\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BuiltinLetArgsNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BuiltinLetArgsNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a!%+-:=^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH##\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoPrefix\NUL#\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNormalOptionMaybeBraceExpansion\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCaseAlt\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCaseIn\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCaseAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCaseAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCaseAltEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCaseAltEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCaseAltEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CaseClosedPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CaseClosedPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCaseExpr\NUL\\\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCaseExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCaseExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH;|\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH;;\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH;&\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCaseIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCaseIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CaseClosedPattern\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CaseClosedPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[@]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[*]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SOH%%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\SOH##\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX#%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT+-=?\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AlternateValuePrefix\SOH//\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceSubst\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceSubst\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\DC1\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX);`\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&<>\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\SOH((\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL(\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\\\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CommandAssumeEscape\NUL{\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\NUL}\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CommandMaybeGroupEnd\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SOH--\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\NUL-\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\NUL=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandArgMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandArgMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPrefix&>\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&;`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH=(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f0123456789<>\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandArgMaybeRedirection\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CommandAssumeEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CommandAssumeEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CommandMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CommandMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL3(?:}+(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]|(?=[}$'\"`\\\\])))+\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCommandMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCommandMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\STX\178{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\}|{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})*?}|(?R)?+)*?,(?:[^ \t<>|&;{}\\\\`'\"$]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\}|{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})*?}|(?R)?+)*?}\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBraceExpansion\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1IncBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDispatchKeyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDispatchKeyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\SOHif\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\SOHfi\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdone\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOHdo\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aForeach\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSelect\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRepeat\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\SOHin\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDispatchPathBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDispatchPathBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\STX\178{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\}|{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})*?}|(?R)?+)*?,(?:[^ \t<>|&;{}\\\\`'\"$]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\}|{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})*?}|(?R)?+)*?}\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PathBraceExpansion\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1IncBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDispatchStringVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDispatchStringVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH$'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\SOH$\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH${\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$((\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\SOH$(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarNameVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarNameVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\\$(?=[A-Za-z_][A-Za-z0-9_]*|[0-9]+|[-*@?$!#~=^+])\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMVarNamePrefixedWithDollar\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDispatchStringVariables\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarNameVariables\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEscapeMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEscapeMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI-[ao](?=$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN(?:[^] \t]++|\\][^ \t])++\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\SOH! \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\SOH!\t\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\NUL-\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTestMaybeUnary\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam3\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX!-=\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL!\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\t \RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a&();<>|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL#ExprBracketValueMaybeBraceExpansion\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#ExprBracketValueMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL#ExprBracketValueMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprBracketValueRecBrace\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprBracketValueRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprBracketValueRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\t \RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a&();<>|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL#ExprBracketValueMaybeBraceExpansion\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!(?:[^] \t]++|\\](?:[^]]|\\][^ \t]))++\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL!\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketTestMaybeNot\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam1_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam1_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam1_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam2\NUL-\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeUnary2\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam2_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam2_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam2_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX!-=\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETestMaybeBinary2\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<>\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam3_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam3_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketParam3_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f!(?=$|[ \t(])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketValueMaybeGlobRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketValueMaybeGlobRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\181/|(~|\\.\\.?)($|[/ \t<>|&;)])|([^[ \t<>|&;()'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|<[0-9]*-[0-9]*>|\\(([^[()<>'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|<[0-9]*-[0-9]*>)*+(\\)|(?=/)))*+/|\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSExprDblBracketValuePatternPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValuePattern2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValuePattern2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValuePattern2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\t )\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindGroupPattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketValueMaybeGlobRange\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&;>|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSExprDblBracketValuePatternPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSExprDblBracketValuePatternPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL~\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH]]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueTextMaybeEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v%*+,-/:?@^~\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\t )\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindGroupPattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&;|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketValueTextMaybeRange\NUL>\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueTextMaybeEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueTextMaybeEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\]\\](?=($|[ \t;|&)]))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH]]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketValueTextMaybeRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketValueTextMaybeRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI<[0-9]*-[0-9]*>\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL<\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblParenOrSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblParenOrSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULu\\((?=\\(((?:[^`'\"()$]++|\\$\\{[^`'\"(){}$]+\\}|\\$(?=[^{`'\"()])|`[^`]*+`|\\((?1)(?:[)]|(?=['\"])))++)(?:[)](?=$|[^)])|[\"']))|\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\SOH((\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULw\\$\\((?=\\(((?:[^`'\"()$]++|\\$\\{[^`'\"(){}$]+\\}|\\$(?=[^{`'\"()])|`[^`]*+`|\\((?1)(?:[)]|(?=['\"])))++)(?:[)](?=$|[^)])|[\"']))|\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$((\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExprGlobParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExprGlobParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH(#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobPatFlag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\STX\213\\((?=(?:[^ \t\\\\'\"|()`ugeP]*+(?:[ug][0123456789]+|[ugeP](?::(?:[^:'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?::|(?=[|()]))|\\[(?:[^]'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:\\](?=[|()]))|{(?:[^}'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:}(?=[|()]))|<(?:[^>'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:>|(?=[|()]))|([^ \t<>|&;(){}'\"`\\\\])(?:(?:(?!\\1)[^'`\"\\\\\\1|()])*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:\\1|(?=[|()]))|(?=\\|))|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:\\)(?:[^ \t}<>|&;)]|(?:}+(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]|(?=[}$'\"`\\\\]))))|[ \t|(]|$))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExtGlobPattern\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGlobQualifier\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKExprGlobParenThenPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKExprGlobParenThenPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH(#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GlobPatFlagThenPath\ACK\NUL\NUL\NUL\NUL\NUL\NUL\STX\213\\((?=(?:[^ \t\\\\'\"|()`ugeP]*+(?:[ug][0123456789]+|[ugeP](?::(?:[^:'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?::|(?=[|()]))|\\[(?:[^]'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:\\](?=[|()]))|{(?:[^}'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:}(?=[|()]))|<(?:[^>'`\"\\\\|()]*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:>|(?=[|()]))|([^ \t<>|&;(){}'\"`\\\\])(?:(?:(?!\\1)[^'`\"\\\\\\1|()])*+(?:\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:\\1|(?=[|()]))|(?=\\|))|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`))?)*(?:\\)(?:[^ \t}<>|&;)]|(?:}+(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]|(?=[}$'\"`\\\\]))))|[ \t|(]|$))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExtGlobPatternThenPath\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGlobQualifier\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExprSubDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExprSubDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExtGlobPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExtGlobPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSubPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExtGlobPatternThenPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExtGlobPatternThenPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSubPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS[0-9]+(?=-?(?=$|[ \t<>|&;)]))\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\](?=($|[ \t;|&<>)]))\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\]\\](?=($|[ \t;|&)]))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\181/|(~|\\.\\.?)($|[/ \t<>|&;)])|([^[ \t<>|&;()'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|<[0-9]*-[0-9]*>|\\(([^[()<>'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|<[0-9]*-[0-9]*>)*+(\\)|(?=/)))*+/|\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValueTextPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI!%&*+-/:<=>?^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExprSubDblParen\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaybeArithmeticBrace\SOH##\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoPrefix\NUL#\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL[\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobAnyFlag\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindGlobPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindGlobPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#*?^|~\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindGroupPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3<(?=[0-9]*-[0-9]*>)\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInGlobRange\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindGroupPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindGroupPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH(#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobPatFlag\NUL(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExtGlobPattern\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindNoGroupEndThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindNoGroupEndThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2(?:}+(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]|(?=[}$'\"`\\\\])))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindNormalTextOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindNormalTextOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULL([^[ \t<>|&;()${}'\"`\\\\]+|(?:}+(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]|(?=[}$'\"`\\\\]))))+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#*?^\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\201(?:~(?:/(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[ \t<>|&;()]|$))|(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\/]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+(?:/(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[*?#^~([]|<[0-9]*-[0-9]*>)|(?=\\\\.(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\/]*+(?:\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+/(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[*?#^~([]|<[0-9]*-[0-9]*>)))|\\.\\.?(?=[ \t<>|&;()]|$))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL~\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#*?^|~\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\SOH(#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX([\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\201(?:~(?:/(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[ \t<>|&;()]|$))|(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\/]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+(?:/(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[*?#^~([]|<[0-9]*-[0-9]*>)|(?=\\\\.(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\/]*+(?:\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+/(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[*?#^~([]|<[0-9]*-[0-9]*>)))|\\.\\.?(?=[ \t<>|&;()]|$))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindGlobPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobRangeOrError\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI[0-9]++(?=[<>])\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubRegex\NUL\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL{\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRegexDup\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*+.?^|\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegexDispatchVariables\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#*?^~\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindStringDQPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindStringDQPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindGlobPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GlobRangeOrStringDQ\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSubPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSubPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindGlobPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobRangeOrPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH((\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ForArithmeticExpr\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vForeachWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ForArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ForArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aForeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aForeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vForeachWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vForeachWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vForeachWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a&();<>|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH()\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FunctionNameStart\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\t (\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFunctionNameMaybeBraceExpansion\NUL}\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\DC1\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFunctionNameMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFunctionNameMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FunctionNameRecBrace\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FunctionNameRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FunctionNameRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFunctionNameMaybeBraceExpansion\NUL}\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FunctionNameStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FunctionNameStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#&();<>|\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL{\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL$FunctionNameStartMaybeBraceExpansion\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$FunctionNameStartMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL$FunctionNameStartMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL-\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[:\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlobClass\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobAnyFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobAnyFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlobClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlobClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:]\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGlobModifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGlobModifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXht\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_h\NULs\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGlobModifier_s\SOHgs\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGlobModifier_s\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGlobModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGlobModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGlobModifier_s_PatPrefix\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Pat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Pat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Rep\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSubPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGlobModifier_s_PatPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGlobModifier_s_PatPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH#%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Pat\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX#%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Pat\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Pat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGlobModifier_s_RecursiveRep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGlobModifier_s_RecursiveRep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGlobModifier_s_RecursiveRep\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobModifier_s_Rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGlobModifier_s_RecursiveRep\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobPatFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobPatFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIncGlobPatFlag\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GlobPatFlagThenPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GlobPatFlagThenPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIncGlobPatFlag\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGlobQualifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGlobQualifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US%*-./=@ADEFGIMNRSTUWX^bcnprstwx\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPe\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_e\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgu\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_u\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXacm\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_a\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOo\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_o\NULf\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_f\NUL+\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_+\NULd\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_d\NULL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_L\NULY\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_Y\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGlobModifier\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US[^*?#^~[ \t<>|&;()${}'\"`\\\\=,\\[]+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_L\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_L\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGKMPTgkmpt\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f+-0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_Y\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_Y\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_Y\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMdhmsw\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f+-0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_Y\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX),\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e[\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e<\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e{\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_ex\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2IncGlobQualifier_e\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2IncGlobQualifier_e\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_ex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_ex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2IncGlobQualifier_e\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_e{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2IncGlobQualifier_e\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r+-0123456789=\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fo\NUL?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fo\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f[\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f<\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f{\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fx\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_fx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobQualifier_f{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_o\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_o\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLNacdlmn\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_u\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_u\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_Y\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGlobQualifier_e\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobRangeOrError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGlobRangeOrError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobRangeOrPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GlobRangeOrPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GlobRangeOrStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GlobRangeOrStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGroupEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalways\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHereDoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHereDoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULD<<-[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${}'\"`\\\\]*))(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!<<-[ \t]*([^ \t<>|&;()]+)(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocINQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULC<<[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${}'\"`\\\\]*))(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL <<[ \t]*([^ \t<>|&;()]+)(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocNQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL<(<<-[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${}'\"`\\\\]*)))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(<<-[ \t]*([^ \t<>|&;()]+))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocINQCmd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL;(<<[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${}'\"`\\\\]*)))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(<<[ \t]*([^ \t<>|&;()]+))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocNQCmd\SOH<<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZshOneLine\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocRemainder\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocINQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocINQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocINQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocINQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\t*%1$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\t*%2$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocNQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocNQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocNQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocNQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%1$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%2$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocRemainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocRemainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&;`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZshOneLine\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocVariables\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarNameVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[0-9a-fA-F_]+\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInGlobRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInGlobRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1IncBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1IncBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\211{(?=-?([0-9]+|[a-zA-Z!#$%*+,-./:=?@^_~]|\\$([#+^=~]*([_a-zA-Z0-9]+|[*@#])(\\[((\\$[#+^=~]*)?([-+_a-zA-Z0-9]+|[*@])|$#)\\])?|#|'(\\\\.|[^'\\\\])')|\\\\.|'[^'\\\\]'|\"(\\\\.|[^\"\\\\`])\"|`[^`]*`)\\.\\.-?([0-9]+|[a-zA-Z!#$%*+,-./:=?@^_~]|\\$([#+^=~]*([_a-zA-Z0-9]+|[*@#])(\\[((\\$[#+^=~]*)?([-+_a-zA-Z0-9]+|[*@])|$#)\\])?|#|'(\\\\.|[^'\\\\])')|\\\\.|'[^'\\\\]'|\"(\\\\.|[^\"\\\\`])\"|`[^`]*`)(\\.\\.-?([0-9]+|\\$([#+^=~]*([_a-zA-Z0-9]+|[*@#])(\\[((\\$[#+^=~]*)?([-+_a-zA-Z0-9]+|[*@])|$#)\\])?|#|'(\\\\.|[^'\\\\])')))?})\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SequenceExpression\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL((?:{([^ \t<>|&;{}\\\\`'\"$/{},]++|(?R))+?})+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIncGlobPatFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIncGlobPatFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO,BIMUabceilmsu\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULq\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGlobQualifier\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2IncGlobQualifier_e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2IncGlobQualifier_e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIncPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIncPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExprGlobParen\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULA(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaybeGlobRangeOrPop\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleGlob\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT(<{}\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULC(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\=/]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+\SOH\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaybeArithmeticBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaybeArithmeticBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMaybeBracketExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMaybeBracketExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\[\\[(?=$|[ \t(])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\[(?=$|[ \t])\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaybeGlobRangeOrPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaybeGlobRangeOrPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindGlobRangeThenPop\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2(?:}+(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]|(?=[}$'\"`\\\\])))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a[^][()]\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKExprGlobParenThenPath\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNormalOptionMaybeBraceExpansion\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindNormalTextOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaybeGlobRangeOrPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNormalOptionMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNormalOptionMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4NormalOptionRecBrace\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalOptionMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindNoGroupEndThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4NormalOptionRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4NormalOptionRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExprGlobParen\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNormalOptionMaybeBraceExpansion\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaybeGlobRangeOrPop\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNotCond2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNotCond2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNotCond2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH!\t\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH! \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SO\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH0x\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\SOH0X\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[1-9][0-9_]*+#\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBaseN\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\201(?:[0-9]++[_0-9]*+)(\\.((?:[0-9]++[_0-9]*+)(?:[eE][-+]?(?:[0-9]++[_0-9]*+))?+|(?:[eE][-+]?(?:[0-9]++[_0-9]*+)))?|(?:[eE][-+]?(?:[0-9]++[_0-9]*+)))?|\\.(?:[0-9]++[_0-9]*+)(?:[eE][-+]?(?:[0-9]++[_0-9]*+))?\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL.\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PathBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PathBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PathBraceExpansion2\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PathBraceExpansion2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PathBraceExpansion2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDispatchPathBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPathRecBrace\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PathMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PathMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindNoGroupEndThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPathRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPathRecBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIncPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\t &);>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIncPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PathMaybeGroupEnd\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\t &);>`|}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIncPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPrefix&>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPrefix&>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH>|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH>!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX!>|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSRecursiveAlternatePatternValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSRecursiveAlternatePatternValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRecursiveAlternateValue\NUL}\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindStringDQPattern\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRecursiveAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRecursiveAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRecursiveAlternateValue\NUL}\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRecursiveVarBraceModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRecursiveVarBraceModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL}\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexCharClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexCharClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RegexCharClassSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RegexCharClassSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH[:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexCharClass\SOH[.\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexCollatingSymbols\SOH[=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexEquivalenceClass\NUL[\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexCollatingSymbols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexCollatingSymbols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegexDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegexDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRegexDup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRegexDup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexEquivalenceClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexEquivalenceClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSx[0-9a-fA-F]{1,2}|[0-7]{1,3}|.\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH-]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexInCharEnd\NUL-\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL[\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RegexCharClassSelect\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\t ()\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexInCharEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexInCharEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL-\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegularAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegularAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RepeatArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RepeatArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RepeatArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSelectIn\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSelectIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSelectIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SequenceExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SequenceExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v-0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH..\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL/\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SOH((\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblParenOrSubShell\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMaybeBracketExpression\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\SOH&>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPrefix&>\SOH&!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&;|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL:[A-Za-z_][A-Za-z0-9_]*(?=\\+?=|\\[(?:$|[^]]))|[0-9]+(?=\\+?=)\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarAssign\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\t\n !&()*+,;<=>?\\`{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDispatchKeyword\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\t\n !&()*+,;<=>?\\`{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgetln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypeset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoglob\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoproc\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[^*?#^~[ \t<>|&;()${}'\"`\\\\=]*+[ \t]*\\(\\)\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\t\n !&()*+,;<=>?\\`{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautoload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abindkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbye\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomparguments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcompcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcompdescribe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcompfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncompgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcompquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomptags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomptry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncompvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdirs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdisown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKechotc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKechoti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aemulate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjobs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnocorrect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnoglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrehash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsched\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKttyctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKulimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunhash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzcompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzmodload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nzparseopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzprof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzpty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vzregexparse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTztcp\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\t\n !&()*+,;<=>?\\`{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaclocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXapm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bapmsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aapropos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aarecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTas86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautoconf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautoheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautomake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQb2sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbison\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abunzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbzip2recover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXc++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acd-read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdda2wav\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncdparanoia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdrdao\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcksum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclang++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXco\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcpio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acrontab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdcop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdeallocvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdiff3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdircolors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdirectomatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdnsdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdumpkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfgconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKflex++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXg++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agettext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngettextize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgimp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgimp-remote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgimptool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgocr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgzexe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahexdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhostid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQigawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkbd_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akbdrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akdialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akillall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTld86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXldd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadunimap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blockfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlsattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlsmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlsmod.old\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlynx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blzmainfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amapscrn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmd5sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmkfifo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmknod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmktemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnano\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnisdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnm86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnohup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopenvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpasswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaste\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apathchk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcregrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcretest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKperror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpidof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpinky\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprocmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprune\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bps2ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2epsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2frag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKps2pdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQps2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsbook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsnup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsresize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstops\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brealpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresizecons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trun-parts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKruncon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetleds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetmetamode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetterm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asha1sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha224sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha256sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha384sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha512sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQskill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKslogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTssed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assh-add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tssh-agent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nssh-keygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vssh-keyscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdbuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsudo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsuidperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsvn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btempfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtouch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKumount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\runicode_start\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funicode_stop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuniq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bupdatedb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuptime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\butmpdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auuidgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalgrind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXvi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXwc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhatis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awhereis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhoami\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxargs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxdg-open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmodmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fypdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTznew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsoelim\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f0123456789<>\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCommandMaybeRedirection\NUL)\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMaybeGroupEnd\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH! \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringDQEscape\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMStringDQDispatchVariables\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMStringDQDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMStringDQDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarNameVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringDQEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringDQEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH\\\"\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\`\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\$\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL3\\\\(?:[abefnrtv\\\\']|[0-7]{1,3}|x[A-Fa-f0-9]{1,2}|c.)\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v-0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubscript2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubscript2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubscript2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindGroupPattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVariableOrSubscriptPos\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE!%&*+-/:<=>?@^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL.(?:-(?:e[fq]|[nolg]t|[nlg]e)|==?|!=)(?=$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETestMaybeBinary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETestMaybeBinary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f=~(?=$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketRegex\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTestMaybeUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTestMaybeUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&-[abcdefghknoprstuvwxzLOGNS](?=$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeUnary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeUnary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULb-[abcdefghknoprstuvwxzLOGNS](?=$|[ \t])(?!\\s+(?:=~|(?:-(?:e[fq]|[nolg]t|[nlg]e)|==?|!=)(?=$|[ \t])))\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketUnary\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\SOH+=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_h\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_h\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceModifier_s_Str\NUL\\\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceModifier_s_Rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceModifier_s_Rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRecursiveVarBraceModifier_s\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceModifier_s_Str\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceModifier_s_Str\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceModifier_s_Rep\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRecursiveVarBraceModifier_s\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarBraceModifiers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarBraceModifiers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXht\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_h\NULs\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_s\SOHgs\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VarBraceModifier_s\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarFlags\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlagsVar\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceStartRecursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceStartRecursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH${\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$((\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\SOH$(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\NUL$\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH#%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVarBraceSubstPat\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX#%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVarBraceSubstPat\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVarBraceSubstPat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVarBraceSubstPat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVarBraceSubstPat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRecursiveAlternateValue\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSubPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l[\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l<\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l{\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l(\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_lx\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH)(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l(s\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l(s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l(s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH)(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH><\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l<s\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l<s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l<s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH><\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH][\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l[s\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l[s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l[s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH][\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_lx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_lx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK(%1)%1\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_lxs\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_lxs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_lxs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT%1%1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_l{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH}{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l{s\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l{s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_l{s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH}{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_pl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_pl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl[\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl<\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl{\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl(\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_plx\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH)(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl(s\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl(s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl(s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH)(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps(\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH><\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl<s\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl<s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl<s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH><\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps<\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH][\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl[s\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl[s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl[s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH][\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps[\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_plx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_plx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK(%1)%1\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_plxs\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_plxs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_plxs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT%1%1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_psx\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_pl{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH}{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl{s\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl{s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlag_pl{s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH}{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps{\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps[\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps<\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps{\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps(\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_psx\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\\$([A-Za-z_][A-Za-z0-9_]*|[0-9]+)(?=\\))\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\\$([A-Za-z_][A-Za-z0-9_]*|[0-9]+)(?=>)\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\\$([A-Za-z_][A-Za-z0-9_]*|[0-9]+)(?=\\])\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_psx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_psx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULE\\$(?!%1)(?:[A-Za-z_](?:(?!%1)[A-Za-z0-9_])*+|(?:(?!%1)[0-9])++)(?=%1)\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^%1]+\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlag_ps{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\\$([A-Za-z_][A-Za-z0-9_]*|[0-9]+)(?=})\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s[\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s<\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s{\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s(\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_sx\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_sx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_sx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_s{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarFlags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarFlags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*#%*+-0@ABCDEFLMNOPQRSUVWXabcefikmnoqtuvwz~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQZ_gjs\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_s\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIlr\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_l\NULp\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlagsSubs\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlagsVar\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlagsSubs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarFlagsSubs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)#+-0@ABCDEFLMNOPQRSUVWXabcefikmnopqtuvwz~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXZg\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarFlag_s\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX_js\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_ps\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIlr\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarFlag_pl\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlagsVar\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlagsVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarFlagsVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL$\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVarBraceStartRecursive\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#+=^~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$*-?@\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\b\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\SOH!}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubShell\NUL!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetopts\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinGetopts\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBuiltinLet\DC1\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX-.:\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarNameArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarNameArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX+-\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\NUL=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL[\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarNameArg\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANVarNameDispatchModifiers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANVarNameDispatchModifiers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\SOH:a\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:A\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:c\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:e\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:h\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_h\SOH:l\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:p\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:P\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:q\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:Q\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:r\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:s\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_s\SOH:t\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_h\SOH:u\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:x\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH:&\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX:gs\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_s\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_h\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_h\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarNameModifier_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKVarNameModifier_s_Str\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKVarNameModifier_s_Rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKVarNameModifier_s_Rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\t &();<>|\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKVarNameModifier_s_Str\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKVarNameModifier_s_Str\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKVarNameModifier_s_Rep\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarNameParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarNameParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVarNameSubstLen\NUL+\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarNameParam+\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX=^~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVarNameSubstLen\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarNameParam+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarNameParam+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVarNameSubstLen\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMVarNamePrefixedWithDollar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMVarNamePrefixedWithDollar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\b\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK!$*-?@\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\NUL#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVarNameSubstLen\NUL+\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarNameParam+\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX=^~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarNameParam\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVarNameSubstLen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVarNameSubstLen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK!$*-?@\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\b\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAfterVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH0x\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\SOH0X\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v0123456789_\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVarSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVarSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarOffset\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r!%&*+-/<=>^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL!\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVariableOrSubscriptPos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNVariableOrSubscriptPos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULA(?:[^*?#^~[ \t<>|&;()${}'\"`\\\\]*+(?:\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZshOneLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZshOneLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL+Jonathan Poelen (jonathan.poelen@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.sh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.zsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.zshrc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.zprofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.zlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.zlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.profile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart"
